pub struct Tui<'a, B: Backend> {
pub sender: Sender<Event>,
/* private fields */
}Fields
sender: Sender<Event>Implementations
Sourceimpl<B: Backend> Tui<'_, B>
impl<B: Backend> Tui<'_, B>
pub fn new(terminal: Terminal<B>) -> Self
pub fn run_loop(&mut self, app: &mut App) -> Result<()>
Sourcepub fn init(&mut self) -> Result<()>
pub fn init(&mut self) -> Result<()>
Initializes the TUI.
get ready for TUI, enable the raw mode and set terminal props.
pub fn term(&mut self) -> Result<()>
pub fn is_running(&self) -> bool
Sourcepub fn exit(&mut self) -> Result<()>
pub fn exit(&mut self) -> Result<()>
Exits the TUI.
cleanup for TUI, disable the raw mode and set terminal props.
pub fn set_search_text(&mut self, text: &str)
pub fn handle_refresh_event(&mut self, _app: &mut App) -> Result<()>
pub fn handle_mouse_events( &mut self, mouse_event: MouseEvent, app: &mut App, ) -> Result<()>
pub fn handle_key_events( &mut self, key_event: KeyEvent, app: &mut App, ) -> Result<()>